@@ -3,7 +3,7 @@ use std::{fs, io};
 #[derive(thiserror::Error, Debug)]
 pub enum DownloadError {
     #[error("HTTP error while downloading file: {0}")]
-    HttpError(#[from] reqwest::Error),
+    HttpError(#[from] ureq::Error),
 
     #[error("IO error while downloading file: {0}")]
     IoError(#[from] std::io::Error),
@@ -27,10 +27,10 @@ pub fn download_file(
     uri: impl AsRef<str>,
     destination: impl AsRef<std::path::Path>,
 ) -> Result<(), DownloadError> {
-    let response = reqwest::blocking::get(uri.as_ref())?;
-    let mut content = io::Cursor::new(response.bytes()?);
+    let response = ureq::get(uri.as_ref()).call()?;
+    let mut reader = response.into_reader();
     let mut file = fs::File::create(destination.as_ref())?;
-    io::copy(&mut content, &mut file)?;
+    io::copy(&mut reader, &mut file)?;
 
     Ok(())
 }
