@@ -7,17 +7,10 @@
 #![warn(unused_crate_dependencies)]
 // https://rust-lang.github.io/rust-clippy/stable/index.html
 #![warn(clippy::pedantic)]
-// Re-disable pedantic lints that are currently failing, until they are triaged and fixed/wontfixed.
-// https://github.com/heroku/libherokubuildpack/issues/16
-#![allow(clippy::doc_markdown)]
-// https://github.com/heroku/libherokubuildpack/issues/13
+// In most cases adding error docs provides little value.
 #![allow(clippy::missing_errors_doc)]
-// https://github.com/heroku/libherokubuildpack/issues/15
-#![allow(clippy::missing_panics_doc)]
-// https://github.com/heroku/libherokubuildpack/issues/24
+// This lint is too noisy and enforces a style that reduces readability in many cases.
 #![allow(clippy::module_name_repetitions)]
-// https://github.com/heroku/libherokubuildpack/issues/14
-#![allow(clippy::must_use_candidate)]
 
 pub use crate::fs::*;
 pub use crate::tar::*;
